import React from 'react';
import '../../../css/endo/GridData.css';
import { getBorderStyle, getIsCellSelected } from './selectionUtils';
import { calculateCurrentSheetView } from './sheetViewUtils';
import { classNames } from '../../utils/classNames';
import { cellInSearch, getColumnIDsArrayFromSheetDataArray } from './utils';
import { TaskpaneType } from '../taskpanes/taskpanes';
import { formatCellData } from './gridDataUtils';
const GridData = (props) => {
    const currentSheetView = calculateCurrentSheetView(props.gridState);
    const sheetData = props.sheetData;
    return (React.createElement(React.Fragment, null, sheetData && sheetData.numRows > 0 && Array(currentSheetView.numRowsRendered).fill(0).map((_, _rowIndex) => {
        const rowIndex = currentSheetView.startingRowIndex + _rowIndex;
        const columnIDs = getColumnIDsArrayFromSheetDataArray([sheetData])[0];
        const rowClassNames = classNames('row', {
            'row-even': rowIndex % 2 === 0,
            'row-odd': rowIndex % 2 !== 0
        });
        return (React.createElement("div", { className: rowClassNames, key: rowIndex }, Array(currentSheetView.numColumnsRendered).fill(0).map((_, _colIndex) => {
            var _a, _b;
            const columnIndex = currentSheetView.startingColumnIndex + _colIndex;
            const columnMitoType = sheetData.columnMitoTypeMap[columnIDs[columnIndex]];
            const cellData = (_b = (_a = props.sheetData) === null || _a === void 0 ? void 0 : _a.data[columnIndex]) === null || _b === void 0 ? void 0 : _b.columnData[rowIndex];
            if (cellData === undefined) {
                return null;
            }
            const className = classNames('cell', {
                'cell-selected': getIsCellSelected(props.gridState.selections, rowIndex, columnIndex),
                'cell-hidden': props.editorState !== undefined && props.editorState.rowIndex === rowIndex && props.editorState.columnIndex === columnIndex,
                'cell-searched': cellInSearch(cellData, props.gridState.searchString) && props.uiState.currOpenTaskpane.type === TaskpaneType.SEARCH,
            });
            const cellWidth = props.gridState.widthDataArray[props.gridState.sheetIndex].widthArray[columnIndex];
            // If the cell is a number, format the data with commas
            const displayCellData = formatCellData(cellData, columnMitoType);
            return (React.createElement("div", { className: className, key: columnIndex, style: Object.assign({ width: `${cellWidth}px` }, getBorderStyle(props.gridState.selections, rowIndex, columnIndex, sheetData.numRows)), tabIndex: -1, "mito-col-index": columnIndex, "mito-row-index": rowIndex, title: displayCellData }, displayCellData));
        })));
    })));
};
export default React.memo(GridData);
//# sourceMappingURL=GridData.js.map