/*
    For a cell to be formatted as a number, the cell must only contain valid number symbols
    and the columnMitoType must be a number_series.

    Note: The cellData type of a float is a string.
*/
export const displayCellAsNumber = (cellData, columnMitoType) => {
    // If the column is not a number series, then don't format the cell as a number
    if (columnMitoType !== "number_series" /* NUMBER_SERIES */) {
        return false;
    }
    if (typeof cellData === 'boolean') {
        return false;
    }
    else if (typeof cellData === 'number') {
        return true;
    }
    else {
        return isStringNumeric(cellData);
    }
};
/*
    Determines if a string is a number
    Adapted from: https://stackoverflow.com/questions/175739/how-can-i-check-if-a-string-is-a-valid-number
    Note: This won't format numbers that have non . separators correctly, but that's okay for now because we wouldn't want to switch them to decimals
*/
export const isStringNumeric = (str) => {
    if (typeof str != "string")
        return false; // we only process strings!  
    return !isNaN(str) && // use type coercion to parse the _entirety_ of the string (`parseFloat` alone does not do this)...
        !isNaN(parseFloat(str)); // ...and ensure strings of whitespace fail
};
/*
    Returns cellData formatted as a number with decimals if the cell only contains valid number symbols
    and the columnMitoType is a number_series. Otherwise, returns the unaltered cellData
*/
export const formatCellData = (cellData, columnMitoType) => {
    if (displayCellAsNumber(cellData, columnMitoType)) {
        // TODO: Let users configure what Locale they use. Alternativly, if we don't pass a locale
        // then it uses the locale set by the javascript runtime. 
        return Number(cellData).toLocaleString("en-US");
    }
    else {
        return '' + cellData;
    }
};
//# sourceMappingURL=gridDataUtils.js.map