// Copyright (c) Mito
import React, { useState } from 'react';
import { ModalEnum } from './modals';
import BlueMitoFolk from '../icons/mitofolks/BlueMitoFolk';
import PinkMitoFolk from '../icons/mitofolks/PinkMitoFolk';
import YellowMitoFolk from '../icons/mitofolks/YellowMitoFolk';
import '../../../css/signup-modal.css';
import TextButton from '../elements/TextButton';
import Input from '../elements/Input';
/*
    This file contains all the screens used in the signup modal. As these
    are only used in this one file, we keep them together for cleanlyness.
*/
// If the user signs up for pro, this is the access code they must put in
const ACCESS_CODE = 'mito-pro-access-code-UEKXPTTQECAULCMW';
/* Step one requires an email input */
const StepOne = (props) => {
    const onSubmit = async (e) => {
        e.preventDefault();
        await props.mitoAPI.sendSignUp(props.email);
        props.next();
    };
    return (React.createElement("div", { className: 'signup-modal-left-column' },
        React.createElement("div", null,
            React.createElement("h1", { className: 'mt-0' }, "Sign Up for Mito"),
            React.createElement("p", { className: 'signup-modal-text' }, "We\u2019ll send you periodic product updates and welcome any feedback. And no spam. Duh.")),
        React.createElement("form", { className: 'signup-modal-email-form', onSubmit: onSubmit },
            React.createElement("h3", { className: 'mb-5px' }, "Your Email"),
            React.createElement(Input, { value: props.email, onChange: (event) => { props.setEmail(event.target.value); }, type: 'email', width: 'large', placeholder: 'example@gmail.com', required: true, autoFocus: true }),
            React.createElement("h3", { className: 'mt-10px mb-5px' }, "Your Company/Organization"),
            React.createElement(Input, { value: props.company, onChange: (event) => { props.setCompany(event.target.value); }, type: 'text', width: 'large', placeholder: 'AppleSoftBook', required: true }),
            React.createElement("div", { className: 'mt-10px' },
                React.createElement(TextButton, { variant: 'dark', width: 'large', type: 'submit' }, "Sign Up")))));
};
/**
 * Step one requires the user to read the privacy policy, and optionally
 * gives the user the chance to sign up for Mito pro.
 *
 * We make this part of step two rather than a whole new step in it's own
 * right as it is branches, and we don't want to deal with that complexity
 * in the main signup flow.
 *  */
const StepTwo = (props) => {
    // We cache isPro so that if the user signs up for pro we can
    // update this immediately with no lag
    const [isPro, setIsPro] = useState(props.isPro);
    const [enteringProAccessCode, setEnteringProAccessCode] = useState(false);
    const [accessCode, setAccessCode] = useState('');
    const [invalidAccessCode, setInvalidAccessCode] = useState(false);
    const attemptSubmitAccessCode = () => {
        if (accessCode !== ACCESS_CODE) {
            setInvalidAccessCode(true);
            return;
        }
        setInvalidAccessCode(false);
        setEnteringProAccessCode(false);
        setIsPro(true);
        // We log this before going pro so that this is the last thing to appear in the logs
        void props.mitoAPI.sendLogMessage('signup_completed_pro');
        void props.mitoAPI.goPro();
    };
    return (React.createElement(React.Fragment, null,
        !enteringProAccessCode &&
            React.createElement("div", { className: 'signup-modal-left-column' },
                React.createElement("div", null,
                    React.createElement("h1", { className: 'mt-0' }, isPro
                        ? "You've Signed up for Mito Pro!"
                        : "Mito Starter Collects Private Telemetry"),
                    React.createElement("p", { className: 'signup-modal-text' },
                        isPro
                            ? "Since you're using Mito Pro, we collect no telemetry, ever."
                            : "We don't collect any information about your data, just basic information like what buttons you click.",
                        ' ',
                        "Read our privacy policy ",
                        React.createElement("a", { href: 'https://privacy.trymito.io/privacy-policy', target: '_blank', rel: "noreferrer" },
                            React.createElement("u", null, "here")),
                        "."),
                    !isPro &&
                        React.createElement("form", { id: 'mito-pro-signup', action: "https://jl76z192i0.execute-api.us-east-1.amazonaws.com/Prod/create_checkout_session/", method: "POST", target: "_blank" },
                            React.createElement("input", { type: "hidden", name: "inapp", value: "true" }),
                            React.createElement("p", { className: 'signup-modal-pro-text mt-10px', onClick: () => {
                                    // We do this as an on click and not as a submit
                                    // so that we can both setEnteringProAccessCode to true,
                                    // and also submit the form
                                    setEnteringProAccessCode(true);
                                    const form = document.getElementById('mito-pro-signup');
                                    form === null || form === void 0 ? void 0 : form.submit();
                                    void props.mitoAPI.sendLogMessage('signup_clicked_pro');
                                } }, "Want to remove telemetry? Get Mito pro \u2192"))),
                React.createElement("div", { className: 'signup-modal-buttons mt-10px' },
                    React.createElement(TextButton, { variant: 'light', width: 'small', onClick: props.back }, "Back"),
                    React.createElement(TextButton, { variant: 'dark', width: 'small', onClick: props.next, autoFocus: true }, "Accept"))),
        enteringProAccessCode &&
            React.createElement("div", { className: 'signup-modal-left-column' },
                React.createElement("div", null,
                    React.createElement("h1", { className: 'mt-0' }, "Complete Pro Signup"),
                    React.createElement("p", { className: 'signup-modal-text' },
                        "Complete the checkout flow. In the Pro documentation, click ",
                        React.createElement("b", null, "Get Access Code"),
                        " and enter it here."),
                    React.createElement("label", null,
                        React.createElement("h3", { className: 'mt-5px mb-10px' }, "Access Code:")),
                    React.createElement(Input, { placeholder: 'mito-pro-access-code-XXXXXXXXXXXX', value: accessCode, onChange: (e) => { setAccessCode(e.target.value); }, onKeyDown: (e) => {
                            if (e.key === 'Enter') {
                                attemptSubmitAccessCode();
                            }
                        } }),
                    invalidAccessCode &&
                        React.createElement("p", { className: 'signup-modal-text signup-modal-text-error' }, "Invalid access code")),
                React.createElement("div", { className: 'signup-modal-buttons mt-10px' },
                    React.createElement(TextButton, { variant: 'light', width: 'small', onClick: () => {
                            setEnteringProAccessCode(false);
                        } }, "Back"),
                    React.createElement(TextButton, { variant: 'dark', width: 'small', onClick: attemptSubmitAccessCode, autoFocus: true }, "Submit")))));
};
/* Step three asks the user want they want to use Mito for */
const StepThree = (props) => {
    const FirstQuestion = 'Where did you hear about Mito?';
    const FirstPlaceholder = 'The Borking Dog channel on YouTube';
    const onSubmit = async (e) => {
        e.preventDefault();
        // Log the answers to the questions each as their own piece of feedback
        await props.mitoAPI.sendFeedback("company/organization" /* COMPANY */, props.numUsages, [{ 'question': 'company/organization', 'answer': props.company }]);
        await props.mitoAPI.sendFeedback("source" /* SOURCE */, props.numUsages, [{ 'question': FirstQuestion, 'answer': props.firstResponse }]);
        // Advance to the next step
        props.next();
    };
    return (React.createElement("div", { className: 'signup-modal-left-column' },
        React.createElement("form", { onSubmit: onSubmit },
            React.createElement("div", null,
                React.createElement("h1", { className: 'mt-0' }, "One Last Question.."),
                React.createElement("label", null,
                    React.createElement("h3", { className: 'mt-0 mb-10px' }, FirstQuestion)),
                React.createElement(Input, { value: props.firstResponse, onChange: (e) => { props.setFirstResponse(e.target.value); }, placeholder: FirstPlaceholder, required: true, autoFocus: true })),
            React.createElement("div", { className: 'mt-50px signup-modal-buttons' },
                React.createElement(TextButton, { variant: 'light', width: 'small', 
                    /* For some reason, we have to make this a button so it doesn't get auto clicked */
                    type: 'button', onClick: props.back }, "Back"),
                React.createElement(TextButton, { variant: 'dark', width: 'small', type: 'submit' }, "Finish")))));
};
/*
    First signup modal, which collects the users email, shows them the privacy policy,
    and then asks them what they want to do with the tool.
*/
const SignupModal = (props) => {
    const [step, setStep] = useState(1);
    const [email, setEmail] = useState('');
    const [company, setCompany] = useState('');
    // Store the first and second response here, so if they use the back button, their answers are stored
    const [firstResponse, setFirstResponse] = useState('');
    const next = () => {
        // Note that if the user is pro, we don't show them the final signup step
        // as we don't collect that data anyways
        if (step + 1 > 3 || (step + 1 > 2 && props.isPro)) {
            props.setUIState((prevUIState) => {
                return Object.assign(Object.assign({}, prevUIState), { currOpenModal: { type: ModalEnum.None } });
            });
            void props.mitoAPI.sendLogMessage('finished_signup');
        }
        else {
            const newStep = Math.min(step + 1, 3);
            setStep(newStep);
            void props.mitoAPI.sendLogMessage('switched_signup_step', {
                'old_signup_step': step,
                'new_signup_step': newStep
            });
        }
    };
    const back = () => {
        const newStep = Math.max(step - 1, 0);
        setStep(newStep);
        void props.mitoAPI.sendLogMessage('switched_signup_step', {
            'old_signup_step': step,
            'new_signup_step': newStep
        });
    };
    // Background colors of the different steps right column
    const backgroundColors = {
        1: '#FFEBEB',
        2: '#FFDAAE',
        3: '#F0C5BB',
    };
    return (React.createElement("div", { className: 'overlay' },
        React.createElement("div", { className: 'signup-modal-container' },
            React.createElement("div", { className: 'signup-modal-left-column-container' },
                step === 1 &&
                    React.createElement(StepOne, { next: next, email: email, setEmail: setEmail, company: company, setCompany: setCompany, mitoAPI: props.mitoAPI }),
                step === 2 &&
                    React.createElement(StepTwo, { next: next, back: back, isPro: props.isPro, mitoAPI: props.mitoAPI }),
                step === 3 &&
                    React.createElement(StepThree, { next: next, back: back, firstResponse: firstResponse, setFirstResponse: setFirstResponse, numUsages: props.numUsages, company: company, mitoAPI: props.mitoAPI })),
            React.createElement("div", { className: 'signup-modal-right-column-container', style: { backgroundColor: backgroundColors[step] } },
                step === 1 &&
                    React.createElement(BlueMitoFolk, null),
                step === 2 &&
                    React.createElement(YellowMitoFolk, null),
                step === 3 &&
                    React.createElement(PinkMitoFolk, null)))));
};
export default SignupModal;
//# sourceMappingURL=SignupModal.js.map